# Copyright (c) 2025 Dedalus Labs, Inc. and its contributors
# SPDX-License-Identifier: MIT

"""Entry point for `python -m slurmq`."""

from slurmq.cli.main import app

if __name__ == "__main__":
    app()
