# Copyright (c) 2025 Dedalus Labs, Inc. and its contributors
# SPDX-License-Identifier: MIT

"""slurmq - Slurm GPU quota monitoring and management."""

from importlib.metadata import version

__version__ = version("slurmq")
VERSION = __version__
